from django.shortcuts import render, redirect
from django.contrib.auth import authenticate, login
from django.contrib.auth.hashers import make_password

from apps.landing.views import landing_page_view
from .forms import LoginForm, UserForm
from .models import MyUser

def register_view(request):
    if request.method == 'POST':
        form = UserForm(request.POST)
        if form.is_valid():
            cd = form.cleaned_data

            # Buat instance MyUser
            # Note: AbstractUser butuh `username` unik. Kita bisa pakai 'nama' dari form sebagai "username".
            user = MyUser(
                username=cd['nama'],  # Kita mapping 'nama' => 'username' 
                email=cd['email'],
                tanggal_lahir=cd['tanggal_lahir'],
                nomor_hp=cd['nomor_hp'],
                url_blog=cd['url_blog'],
                deskripsi_diri=cd['deskripsi_diri'],
                status_pekerjaan=cd['status_pekerjaan'],
                kode_mata_uang=cd['kode_mata_uang'],
                nama_asli=cd['nama'],  # Simpan juga ke field 'nama_asli' (opsional)
            )
            
            # Hash password
            user.set_password(cd['password'])
            
            # Simpan user ke DB
            user.save()
            
            return redirect('login')  # misal, ke halaman login
    else:
        form = UserForm()

    return render(request, 'register.html', {'form': form})

def login_view(request):
    if request.method == 'POST':
        form = LoginForm(request.POST)
        if form.is_valid():
            uname = form.cleaned_data['username']
            pwd = form.cleaned_data['password']
            user = authenticate(request, username=uname, password=pwd)
            if user is not None:
                login(request, user)  # Django buat session
                return redirect(landing_page_view)  # misal, ke halaman utama
            else:
                # Tambahkan pesan error ke form
                form.add_error(None, "Username atau password salah.")
    else:
        form = LoginForm()
    
    return render(request, 'login.html', {'form': form})